==> xl-react-components-0.16.62.tgz: package/tests/e2e/dsl/component/widget/widget-table.js <==
import R from 'ramda';
import {
    Action,
    ActionUtil,
    ElementUtil,
    Expectation,
    WaitCondition,
    XPath
} from 'protractor-base-dsl';
import Spinner from '../../common/spinner';

const tableSelector = '.testComponent .xl-react-widget-table';
const headerSelector = (columnNumber) => `${tableSelector} th:nth-child(${columnNumber})`;

const changePaginationSize = (pageSize) => {
    const action = () => Action.click(`${tableSelector} .react-bs-table-sizePerPage-dropdown button`);
    const condition = () => WaitCondition.displayed(`${tableSelector} .dropdown-menu`);
    ActionUtil.repeatAction(action, condition);
    Action.click(XPath.withLinkContains(`${tableSelector} .dropdown-menu`, pageSize));
};
const expectHeaders = (headers) =>
    R.forEach((ind) => {
        Expectation.textEquals(`${tableSelector} th:nth-child(${ind + 1})`, headers[ind]);
    }, R.range(1, headers.length));

const expectFirstName = (rowNum, text) =>
    Expectation.textEquals(`${tableSelector} tr:nth-child(${rowNum}) td.xl-react-table-firstname`, text);

const expectActivePage = (pageNumber) =>
    `${tableSelector} ul.pagination li.active.page-item[title="${pageNumber}"] a`;

const expectAscOrder = (columnNumber) =>
    Expectation.present(`${headerSelector(columnNumber)} .react-bootstrap-table-sort-order.dropup`);

const expectDescOrder = (columnNumber) => {
    Expectation.present(`${headerSelector(columnNumber)} .react-bootstrap-table-sort-order`);
    Expectation.notPresent(`${headerSelector(columnNumber)} .react-bootstrap-table-sort-order.dropup`);
};

const expectRowToBe = (rowNumber, values) => {
    const cellsSelector = `${tableSelector} tbody tr:nth-child(${rowNumber}) td`;
    element.all(By.css(cellsSelector)).getText().then((cellsText) => {
        if (!R.equals(cellsText, values)) {
            throw new Error(`Expected row values are [${values}], but actual values are [${cellsText}]`);
        }
    });
};

const expectRowNotPresent = (rowNumber) =>
    Expectation.notPresent(`${tableSelector} tr:nth-child(${rowNumber})`);

const expectNoPagination = () =>
    Expectation.notDisplayed(`${tableSelector} .page-item`);

const expectTotal = (total) => {
    const selector = `${tableSelector} .react-bootstrap-table-pagination`;
    Expectation.textMatches(selector, new RegExp(`Total: ${total}`));
};

const expectAtLeastNumberOfRows = (expected) =>
    Expectation.countAtLeast(`${tableSelector} tr`, expected);

const expectNumberOfRows = (expected) =>
    Expectation.count(`${tableSelector} tr`, expected);

const openPage = (pageNumber) =>
    Action.click(`${tableSelector} ul.pagination li.page-item[title="${pageNumber}"] a`);

const expectRowPresent = (rowNumber) =>
    Expectation.present(`${tableSelector} tbody>tr:nth-child(${rowNumber})`);

const expectFiltersPresent = () =>
    Expectation.present(`${tableSelector} thead>tr th .xl-react-widget-filter`);

const openDropdownToggle = () => {
    const cssSelector = `${tableSelector} .dropdown-toggle`;
    const elementFinder = ElementUtil.elementFinder(cssSelector);

    expect(elementFinder.getAttribute('aria-expanded')
        .then((actualText) => {
            if (R.equals(actualText, 'false')) {
                Action.click(cssSelector);
            }
        }));
};

const pageSizeMenu = () =>
    ElementUtil.elementFinder(`${tableSelector} .dropdown-menu`);

const expectPage = (page) =>
    Expectation.textEquals(`${tableSelector} ul.pagination li.active .page-link`, page.toString());

const expectPageSize = (size) =>
    Expectation.textEquals(`${tableSelector} #pagination-size-per-page`, size.toString());

const expectPageSizes = (sizes) => {
    openDropdownToggle();
    Expectation.count(`${tableSelector} .dropdown-menu li`, sizes.length);
    for (const size of sizes) {
        Expectation.displayed(pageSizeMenu()
            .element(By.linkText(`${size}`)));
    }
    openDropdownToggle();
};

const sortColumn = (columnNumber) => Action.click(`${tableSelector} th:nth-child(${columnNumber})`);

const toggleFilters = () => Action.click('.testBindings .xl-react-widget-table-toggle-filters');

const resetAllFilters = () => Action.click('.testBindings .reset-table-filters-button');

const setFilter = (columnNumber, value) =>
    Action.typeText(`${headerSelector(columnNumber)} input`, value);

const resetFilter = (columnNumber) =>
    Action.click(`${headerSelector(columnNumber)} span.xl-react-btn-close`);

const paginationElement = () =>
    ElementUtil.elementFinder(`${tableSelector} ul.pagination`);

const goToCertainPage = (text) => {
    Action.jsClick(paginationElement()
        .element(By.linkText(text.toString())));
    Spinner.noSpinner();
};

const goToPreviousPage = () => goToCertainPage('<');

const goToNextPage = () => goToCertainPage('>');

const goToPage = (page) => goToCertainPage(page);

const toggleMultiSelectColumns = () => Action.click('.testBindings .xl-react-widget-table-toggle-select');

const selectAllRows = () => Action.click(`${tableSelector} th[data-row-selection]`);

const selectRow = (rowIndex) => Action.click(`${tableSelector} tbody tr:nth-child(${rowIndex}) td:nth-child(1)`);

const expectSelected = (selectedRows) =>
    R.forEach((index) => {
        Expectation.checkboxChecked(`${tableSelector} tbody tr:nth-child(${index}) td:nth-child(1) input`, true);
    }, selectedRows);

const WidgetTable = {
    changePaginationSize,
    expectActivePage,
    expectAscOrder,
    expectAtLeastNumberOfRows,
    expectDescOrder,
    expectFiltersPresent,
    expectFirstName,
    expectHeaders,
    expectNumberOfRows,
    expectPage,
    expectPageSize,
    expectPageSizes,
    expectRowNotPresent,
    expectRowPresent,
    expectRowToBe,
    expectNoPagination,
    expectTotal,
    expectSelected,
    goToPreviousPage,
    goToNextPage,
    goToPage,
    openPage,
    resetAllFilters,
    resetFilter,
    selectAllRows,
    selectRow,
    setFilter,
    sortColumn,
    toggleFilters,
    toggleMultiSelectColumns
};
export default WidgetTable;
global.WidgetTable = WidgetTable;

==> xl-react-components-0.21.12.tgz: package/tests/e2e/dsl/component/widget/widget-table.js <==
import R from 'ramda';
import {
    Action,
    ActionUtil,
    ElementUtil,
    Expectation,
    WaitCondition,
    XPath
} from 'protractor-base-dsl';
import Spinner from '../../common/spinner';

const tableSelector = '.testComponent .xl-react-widget-table';
const headerSelector = (columnNumber) => `${tableSelector} th:nth-child(${columnNumber})`;

const changePaginationSize = (pageSize) => {
    const action = () => Action.click(`${tableSelector} .react-bs-table-sizePerPage-dropdown button`);
    const condition = () => WaitCondition.displayed(`${tableSelector} .dropdown-menu`);
    ActionUtil.repeatAction(action, condition);
    Action.click(XPath.withLinkContains(`${tableSelector} .dropdown-menu`, pageSize));
};
const expectHeaders = (headers) =>
    R.forEach((ind) => {
        Expectation.textEquals(`${tableSelector} th:nth-child(${ind + 1})`, headers[ind]);
    }, R.range(1, headers.length));

const expectFirstName = (rowNum, text) =>
    Expectation.textEquals(`${tableSelector} tr:nth-child(${rowNum}) td.xl-react-table-firstname`, text);

const expectActivePage = (pageNumber) =>
    `${tableSelector} ul.pagination li.active.page-item[title="${pageNumber}"] a`;

const expectAscOrder = (columnNumber) =>
    Expectation.present(`${headerSelector(columnNumber)} .react-bootstrap-table-sort-order.dropup`);

const expectDescOrder = (columnNumber) => {
    Expectation.present(`${headerSelector(columnNumber)} .react-bootstrap-table-sort-order`);
    Expectation.notPresent(`${headerSelector(columnNumber)} .react-bootstrap-table-sort-order.dropup`);
};

const expectRowToBe = (rowNumber, values) => {
    const cellsSelector = `${tableSelector} tbody tr:nth-child(${rowNumber}) td`;
    element.all(By.css(cellsSelector)).getText().then((cellsText) => {
        if (!R.equals(cellsText, values)) {
            throw new Error(`Expected row values are [${values}], but actual values are [${cellsText}]`);
        }
    });
};

const expectRowNotPresent = (rowNumber) =>
    Expectation.notPresent(`${tableSelector} tr:nth-child(${rowNumber})`);

const expectNoPagination = () =>
    Expectation.notDisplayed(`${tableSelector} .page-item`);

const expectTotal = (total) => {
    const selector = `${tableSelector} .react-bootstrap-table-pagination`;
    Expectation.textMatches(selector, new RegExp(`Total: ${total}`));
};

const expectAtLeastNumberOfRows = (expected) =>
    Expectation.countAtLeast(`${tableSelector} tr`, expected);

const expectNumberOfRows = (expected) =>
    Expectation.count(`${tableSelector} tr`, expected);

const openPage = (pageNumber) =>
    Action.click(`${tableSelector} ul.pagination li.page-item[title="${pageNumber}"] a`);

const expectRowPresent = (rowNumber) =>
    Expectation.present(`${tableSelector} tbody>tr:nth-child(${rowNumber})`);

const expectFiltersPresent = () =>
    Expectation.present(`${tableSelector} thead>tr th .xl-react-widget-filter`);

const openDropdownToggle = () => {
    const cssSelector = `${tableSelector} .dropdown-toggle`;
    const elementFinder = ElementUtil.elementFinder(cssSelector);

    expect(elementFinder.getAttribute('aria-expanded')
        .then((actualText) => {
            if (R.equals(actualText, 'false')) {
                Action.click(cssSelector);
            }
        }));
};

const pageSizeMenu = () =>
    ElementUtil.elementFinder(`${tableSelector} .dropdown-menu`);

const expectPage = (page) =>
    Expectation.textEquals(`${tableSelector} ul.pagination li.active .page-link`, page.toString());

const expectPageSize = (size) =>
    Expectation.textEquals(`${tableSelector} #pagination-size-per-page`, size.toString());

const expectPageSizes = (sizes) => {
    openDropdownToggle();
    Expectation.count(`${tableSelector} .dropdown-menu li`, sizes.length);
    for (const size of sizes) {
        Expectation.displayed(pageSizeMenu()
            .element(By.linkText(`${size}`)));
    }
    openDropdownToggle();
};

const sortColumn = (columnNumber) => Action.click(`${tableSelector} th:nth-child(${columnNumber})`);

const toggleFilters = () => Action.click('.testBindings .xl-react-widget-table-toggle-filters');

const resetAllFilters = () => Action.click('.testBindings .reset-table-filters-button');

const setFilter = (columnNumber, value) =>
    Action.typeText(`${headerSelector(columnNumber)} input`, value);

const resetFilter = (columnNumber) =>
    Action.click(`${headerSelector(columnNumber)} i.close-icon`);

const paginationElement = () =>
    ElementUtil.elementFinder(`${tableSelector} ul.pagination`);

const goToCertainPage = (text) => {
    Action.jsClick(paginationElement()
        .element(By.linkText(text.toString())));
    Spinner.noSpinner();
};

const goToPreviousPage = () => goToCertainPage('<');

const goToNextPage = () => goToCertainPage('>');

const goToPage = (page) => goToCertainPage(page);

const toggleMultiSelectColumns = () => Action.click('.testBindings .xl-react-widget-table-toggle-select');

const selectAllRows = () => Action.click(`${tableSelector} th[data-row-selection]`);

const selectRow = (rowIndex) => Action.click(`${tableSelector} tbody tr:nth-child(${rowIndex}) td:nth-child(1)`);

const expectSelected = (selectedRows) =>
    R.forEach((index) => {
        Expectation.checkboxChecked(`${tableSelector} tbody tr:nth-child(${index}) td:nth-child(1) input`, true);
    }, selectedRows);

const expectPresentOnPagination = (selector) =>
    Expectation.present(`${tableSelector} .react-bootstrap-table-pagination ${selector}`);

const WidgetTable = {
    changePaginationSize,
    expectActivePage,
    expectAscOrder,
    expectAtLeastNumberOfRows,
    expectDescOrder,
    expectFiltersPresent,
    expectFirstName,
    expectHeaders,
    expectNumberOfRows,
    expectPage,
    expectPageSize,
    expectPageSizes,
    expectPresentOnPagination,
    expectRowNotPresent,
    expectRowPresent,
    expectRowToBe,
    expectNoPagination,
    expectTotal,
    expectSelected,
    goToPreviousPage,
    goToNextPage,
    goToPage,
    openPage,
    resetAllFilters,
    resetFilter,
    selectAllRows,
    selectRow,
    setFilter,
    sortColumn,
    toggleFilters,
    toggleMultiSelectColumns
};
export default WidgetTable;
global.WidgetTable = WidgetTable;
